@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,12 +14,11 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: gsl_sf_clausen.h,v 1.11 2000/05/04 11:25:07 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 #ifndef __GSL_SF_CLAUSEN_H__
 #define __GSL_SF_CLAUSEN_H__
 
@@ -44,8 +43,8 @@ __BEGIN_DECLS
  * Relation to dilogarithm:
  *   Cl_2(theta) = Im[ Li_2(e^(i theta)) ]
  */
-int gsl_sf_clausen_impl(double x, gsl_sf_result * result);
-int gsl_sf_clausen_e(const double x, gsl_sf_result * result);
+int gsl_sf_clausen_e(double x, gsl_sf_result * result);
+double gsl_sf_clausen(const double x);
 
 
 __END_DECLS
